from setuptools import setup, find_packages

setup(
    name='qym',
    version='0.0.1',
    description='quilterai\'s reinforcement learning vectrorized environment interface.',
    author='quilterai',
    author_email='dev@quilter.ai',
    url='https://quilter.ai',
    # packages=find_packages(),
    install_requires=[
        # Add any dependencies your package requires here
    ],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
)